==> gcc-9_9.2.1.orig.tar.gz: gm2/gcc/gm2/gm2-gcc/m2linemap.h <==
/* m2linemap.h header file for m2linemap.c.

Copyright (C) 2012-2019 Free Software Foundation, Inc.
Contributed by Gaius Mulley <gaius@glam.ac.uk>.

This file is part of GNU Modula-2.

GNU Modula-2 is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

GNU Modula-2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Modula-2; see the file COPYING.  If not,
see <https://www.gnu.org/licenses/>.  */

#if !defined(m2linemap_h)

#include "input.h"

#define m2linemap_h
#if defined(m2linemap_c)
#if (__cplusplus)
#define EXTERN extern "C"
#else /* !__cplusplus.  */
#define EXTERN
#endif /*!__cplusplus.  */
#else /* !m2linemap_c.  */
#if (__cplusplus)
#define EXTERN extern "C"
#else /* !__cplusplus.  */
#define EXTERN extern
#endif /* !__cplusplus.  */
#endif /* !m2linemap_c.  */

EXTERN void m2linemap_StartFile (void *filename, unsigned int linebegin);
EXTERN void m2linemap_EndFile (void);
EXTERN void m2linemap_StartLine (unsigned int linenumber,
                                 unsigned int linesize);
EXTERN location_t m2linemap_GetLocationColumn (unsigned int column);

EXTERN location_t m2linemap_UnknownLocation (void);
EXTERN location_t m2linemap_BuiltinsLocation (void);

EXTERN location_t m2linemap_GetLocationColumn (unsigned int column);
EXTERN int m2linemap_GetLineNoFromLocation (location_t location);
EXTERN int m2linemap_GetColumnNoFromLocation (location_t location);
EXTERN const char *m2linemap_GetFilenameFromLocation (location_t location);
EXTERN void m2linemap_ErrorAt (location_t location, char *message);

#undef EXTERN
#endif /* m2linemap_h.  */

==> gcc-9_9.4.0.orig.tar.gz: gm2/gcc/gm2/gm2-gcc/m2linemap.h <==
/* m2linemap.h header file for m2linemap.c.

Copyright (C) 2012-2020 Free Software Foundation, Inc.
Contributed by Gaius Mulley <gaius@glam.ac.uk>.

This file is part of GNU Modula-2.

GNU Modula-2 is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

GNU Modula-2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Modula-2; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

#if !defined(m2linemap_h)

#include "input.h"

#define m2linemap_h
#if defined(m2linemap_c)
#if (__cplusplus)
#define EXTERN extern "C"
#else /* !__cplusplus.  */
#define EXTERN
#endif /*!__cplusplus.  */
#else /* !m2linemap_c.  */
#if (__cplusplus)
#define EXTERN extern "C"
#else /* !__cplusplus.  */
#define EXTERN extern
#endif /* !__cplusplus.  */
#endif /* !m2linemap_c.  */

EXTERN void m2linemap_StartFile (void *filename, unsigned int linebegin);
EXTERN void m2linemap_EndFile (void);
EXTERN void m2linemap_StartLine (unsigned int linenumber,
                                 unsigned int linesize);
EXTERN location_t m2linemap_GetLocationColumn (unsigned int column);

EXTERN location_t m2linemap_UnknownLocation (void);
EXTERN location_t m2linemap_BuiltinsLocation (void);

EXTERN location_t m2linemap_GetLocationColumn (unsigned int column);
EXTERN int m2linemap_GetLineNoFromLocation (location_t location);
EXTERN int m2linemap_GetColumnNoFromLocation (location_t location);
EXTERN const char *m2linemap_GetFilenameFromLocation (location_t location);
EXTERN void m2linemap_ErrorAt (location_t location, char *message);

#undef EXTERN
#endif /* m2linemap_h.  */
